@@ -1,4 +1,4 @@
-library(lavaan)
+suppressWarnings(library(lavaan))
 
 # Define our other variables
 M <- "visual"
@@ -41,6 +41,7 @@ fit.sem2 <- sem(HS.model2, data)
 
 
 test_that("nice_tidySEM on CFA", {
+  skip_if_not_installed("tidySEM")
   expect_s3_class(
     nice_tidySEM(fit.cfa),
     c("gg", "ggplot")
@@ -48,12 +49,14 @@ test_that("nice_tidySEM on CFA", {
 })
 
 test_that("nice_tidySEM wrong labels", {
+  skip_if_not_installed("tidySEM")
   expect_error(
     nice_tidySEM(fit.cfa, label = "wrong.labels")
   )
 })
 
 test_that("nice_tidySEM on CFA with manual structure", {
+  skip_if_not_installed("tidySEM")
   expect_s3_class(
     nice_tidySEM(fit.cfa, layout = manual.structure),
     c("gg", "ggplot")
@@ -61,6 +64,7 @@ test_that("nice_tidySEM on CFA with manual structure", {
 })
 
 test_that("nice_tidySEM on SEM", {
+  skip_if_not_installed("tidySEM")
   expect_s3_class(
     nice_tidySEM(fit.sem),
     c("gg", "ggplot")
@@ -68,6 +72,7 @@ test_that("nice_tidySEM on SEM", {
 })
 
 test_that("nice_tidySEM on SEM with manual structure", {
+  skip_if_not_installed("tidySEM")
   expect_s3_class(
     nice_tidySEM(fit.sem, layout = manual.structure),
     c("gg", "ggplot")
@@ -75,6 +80,7 @@ test_that("nice_tidySEM on SEM with manual structure", {
 })
 
 test_that("nice_tidySEM on SEM with automatic structure", {
+  skip_if_not_installed("tidySEM")
   expect_s3_class(
     nice_tidySEM(fit.sem2, layout = indirect),
     c("gg", "ggplot")
@@ -82,6 +88,7 @@ test_that("nice_tidySEM on SEM with automatic structure", {
 })
 
 test_that("nice_tidySEM on SEM with automatic structure and labels", {
+  skip_if_not_installed("tidySEM")
   expect_s3_class(
     nice_tidySEM(fit.sem2, layout = indirect,
                  label = label),
@@ -91,6 +98,7 @@ test_that("nice_tidySEM on SEM with automatic structure and labels", {
 
 
 test_that("nice_tidySEM on lavaan", {
+  skip_if_not_installed("tidySEM")
   expect_s3_class(
     nice_tidySEM(fit.lavaan),
     c("gg", "ggplot")
@@ -98,6 +106,7 @@ test_that("nice_tidySEM on lavaan", {
 })
 
 test_that("nice_tidySEM on lavaan with manual structure", {
+  skip_if_not_installed("tidySEM")
   expect_s3_class(
     nice_tidySEM(fit.lavaan, layout = manual.structure),
     c("gg", "ggplot")
@@ -105,16 +114,35 @@ test_that("nice_tidySEM on lavaan with manual structure", {
 })
 
 test_that("nice_tidySEM on sem with hide_nonsig_edges", {
+  skip_if_not_installed("tidySEM")
   expect_s3_class(
     nice_tidySEM(fit.sem, hide_nonsig_edges = TRUE),
     c("gg", "ggplot")
   )
 })
 
+test_that("nice_tidySEM on sem with hide_cov", {
+  skip_if_not_installed("tidySEM")
+  expect_s3_class(
+    nice_tidySEM(fit.sem, hide_cov = TRUE),
+    c("gg", "ggplot")
+  )
+})
+
+test_that("nice_tidySEM on sem with reduce_items", {
+  skip_if_not_installed("tidySEM")
+  expect_s3_class(
+    nice_tidySEM(fit.sem, reduce_items = c(x = 0.4, y = 0.2)),
+    c("gg", "ggplot")
+  )
+  expect_error(nice_tidySEM(fit.sem, reduce_items = "not numeric"))
+  expect_error(nice_tidySEM(fit.sem, reduce_items = c(1, 2, 3)))
+})
+
 test_that("nice_tidySEM on sem with plot = FALSE", {
+  skip_if_not_installed("tidySEM")
   expect_s3_class(
     nice_tidySEM(fit.sem, plot = FALSE),
     "sem_graph"
   )
 })
-
